# Core Developers
----------
- Sepand Haghighi - Open Science Laboratory ([Github](https://github.com/sepandhaghighi))
- Sadra Sabouri - Open Science Laboratory ([Github](https://github.com/sadrasabouri))

# Other Contributors
----------
- [@mhmoslemi2338](https://github.com/mhmoslemi2338)
- [@evanofslack](https://github.com/evanofslack)
- [@omahs](https://github.com/omahs)
- [@AHReccese](https://github.com/AHReccese)
